Swoosh.Adapters.Test (Swoosh v1.25.0)

Copy Markdown View Source

An adapter that sends emails as messages to the current process.

This is meant to be used during tests and works with the assertions found in the Swoosh.TestAssertions module.

For feature, browser, and E2E tests where the email is delivered from request-handling or LiveView processes, use the Swoosh.Adapters.Sandbox adapter instead.

Example

# config/test.exs
config :sample, Sample.Mailer,
  adapter: Swoosh.Adapters.Test

# lib/sample/mailer.ex
defmodule Sample.Mailer do
  use Swoosh.Mailer, otp_app: :sample
end

Summary

Functions

deliver(email, config)

Callback implementation for Swoosh.Adapter.deliver/2.

deliver_many(emails, config)

Callback implementation for Swoosh.Adapter.deliver_many/2.

validate_config(config)

Callback implementation for Swoosh.Adapter.validate_config/1.

validate_dependency()

Callback implementation for Swoosh.Adapter.validate_dependency/0.